==> anwiba-commons-swing-core-1.0.25-sources.jar: net/anwiba/commons/swing/component/search/action/CleanAction.java <==
/*
 * #%L
 * anwiba commons swing
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.swing.component.search.action;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;

import net.anwiba.commons.model.IChangeableObjectListener;
import net.anwiba.commons.model.IObjectModel;
import net.anwiba.commons.swing.icon.GuiIcons;
import net.anwiba.commons.utilities.string.StringUtilities;

public final class CleanAction extends AbstractAction {
  private final IObjectModel<String> stringFieldModel;
  private static final long serialVersionUID = 1L;

  public CleanAction(final IObjectModel<String> stringFieldModel) {
    super(null, GuiIcons.EDIT_CLEAR_ICON.getSmallIcon());
    putValue(SHORT_DESCRIPTION, "clear search string field");
    this.stringFieldModel = stringFieldModel;
    stringFieldModel.addChangeListener(new IChangeableObjectListener() {

      @Override
      public void objectChanged() {
        setEnabled(!StringUtilities.isNullOrEmpty(stringFieldModel.get()));
      }
    });
    setEnabled(!StringUtilities.isNullOrEmpty(stringFieldModel.get()));
  }

  @Override
  public void actionPerformed(final ActionEvent e) {
    this.stringFieldModel.set(null);
  }
}

==> anwiba-commons-swing-core-1.0.140-sources.jar: net/anwiba/commons/swing/component/search/action/CleanAction.java <==
/*
 * #%L
 * anwiba commons swing
 * %%
 * Copyright (C) 2007 - 2016 Andreas Bartels
 * %%
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 2.1 of the
 * License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 * 
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-2.1.html>.
 * #L%
 */
package net.anwiba.commons.swing.component.search.action;

import java.awt.event.ActionEvent;

import javax.swing.AbstractAction;

import net.anwiba.commons.model.IChangeableObjectListener;
import net.anwiba.commons.model.IObjectModel;
import net.anwiba.commons.swing.component.search.SearchComponentMessages;
import net.anwiba.commons.swing.icon.GuiIcons;
import net.anwiba.commons.utilities.string.StringUtilities;

public final class CleanAction extends AbstractAction {
  private final IObjectModel<String> stringFieldModel;
  private static final long serialVersionUID = 1L;

  public CleanAction(final IObjectModel<String> stringFieldModel) {
    super(null, GuiIcons.EDIT_CLEAR_ICON.getSmallIcon());
    putValue(SHORT_DESCRIPTION, SearchComponentMessages.ClearCearchStringField);
    this.stringFieldModel = stringFieldModel;
    stringFieldModel.addChangeListener(new IChangeableObjectListener() {

      @Override
      public void objectChanged() {
        setEnabled(!StringUtilities.isNullOrEmpty(stringFieldModel.get()));
      }
    });
    setEnabled(!StringUtilities.isNullOrEmpty(stringFieldModel.get()));
  }

  @Override
  public void actionPerformed(final ActionEvent e) {
    this.stringFieldModel.set(null);
  }
}
